@@ -172,7 +172,7 @@ def readicecubeps(fstream,shp,refiter,dimiter,dimiterpos,refnoiter,dimnoiter,vty
 
 # we kunnen eens proberen om een variabele aan te maken met een vooraf gespecifieerde dimensie!
 
-def pcd(func,dnamsel,datin,datout,appenddim = False, maxmembytes = 10000000):
+def pcd(func,dnamsel,datin,datout,appenddim = False, maxmembytes = 10000000, forcearray=False):
     """ purpose (see also README.md): process binary NetCDF data streams
     func: the function/analysis to be applied on the data input streams
           specified below. The arguments  of func correspond to the respective
@@ -495,8 +495,28 @@ def pcd(func,dnamsel,datin,datout,appenddim = False, maxmembytes = 10000000):
     
     # 'probe' function output dimensions
     dummydat = []
+    shapein = []
     for ivsdin,evsdin in enumerate(vsdin):
-        dummydat.append(np.zeros([len(e) for e in adimfuncin[ivsdin]]))
+        shapein.append([len(e) for e in adimfuncin[ivsdin]])
+
+        # if shapein[ivsdin] == tuple():
+        #     if forcenum and (not forcearray):
+        #         # to do: make it 
+        #         if appenddim == True:
+        #             dummydat.append(0.)
+        #         else:
+        #            raise SomeError('we can not force to be numeric if the option appenddim is switched on')
+        # else: 
+        #     np.zeros(shapein[ivsdin])
+
+    # we are in the special case of an extra dimension to be added to the input
+    if (list() in shapein) and (forcearray):
+        for ivsdin,evsdin in enumerate(vsdin):
+            dummydat.append(np.zeros([1]+shapein[ivsdin]))
+    else:
+        for ivsdin,evsdin in enumerate(vsdin):
+            dummydat.append(np.zeros(shapein[ivsdin]))
+
     ddout =  func(*dummydat)
     if (type(ddout).__name__ == 'tuple'):
         ddout = list(ddout)
@@ -512,7 +532,13 @@ def pcd(func,dnamsel,datin,datout,appenddim = False, maxmembytes = 10000000):
     for iddout in range(len(ddout)):
         if type(ddout[iddout] ) != np.ndarray: 
             ddout[iddout] = np.array(ddout[iddout])
-    
+            # we are in the special case of an extra dimension to be added to the input -> so we remove it again
+        if (list() in shapein) and (forcearray):
+            if len(ddout[iddout].shape) > 1: 
+                ddout[iddout].shape = ddout[iddout].shape[1:]
+            else:
+                ddout[iddout].shape = []
+
         if (len(np.array(ddout[iddout]).shape) != len(adimfuncin[ivsdin])):
             raise SomeError('The amount of input ('+str(len(adimfuncin[ivsdin]))+') and output dimensions ('+str(len(ddout[iddout].shape))+') of function  is not the same')
     
@@ -976,6 +1002,7 @@ def pcd(func,dnamsel,datin,datout,appenddim = False, maxmembytes = 10000000):
         for k in range(lennoapplymax):
             # actually, this is just the end of the file output already written
             ahunkin = []
+            shapein = []
             for ivsdin, evsdin in enumerate(vsdin):
                 pos = 0
                 # e.g. pos = (9)+ 20*(10) + 50*50*20*(5)
@@ -989,9 +1016,16 @@ def pcd(func,dnamsel,datin,datout,appenddim = False, maxmembytes = 10000000):
                             # curaddout = curaddout * dimnoiteroutref[i]
                     pos    = pos    + curadd
                 ahunkin.append(dataicecubein[ivsdin][pos:(pos+alendfuncin[ivsdin])])
-                ahunkin[ivsdin].shape = [len(e) for e in adimfuncin[ivsdin]]
-    
-            # apply the function
+                shapein.append([len(e) for e in adimfuncin[ivsdin]])
+                #ahunkin[ivsdin].shape = [len(e) for e in adimfuncin[ivsdin]]
+            # we are in the special case of an extra dimension to be prepended to the input
+            if (list() in shapein) and (forcearray):
+                for ivsdin,evsdin in enumerate(vsdin):
+                    ahunkin.append(np.zeros([1]+shapein[ivsdin]))
+            else:
+                for ivsdin,evsdin in enumerate(vsdin):
+                    ahunkin.append(np.zeros(shapein[ivsdin]))
+                    # apply the function
     
             ahunkout =  func(*ahunkin)
             if (type(ahunkout).__name__ == 'tuple'):
@@ -1002,6 +1036,14 @@ def pcd(func,dnamsel,datin,datout,appenddim = False, maxmembytes = 10000000):
             for ihunkout in range(len(ahunkout)):
                 ahunkout[ihunkout] = np.array(ahunkout[ihunkout])
                 # e.g. posout = (9)+ 20*(10) + 50*50*20*(5)
+
+                # we are in the special case of an extra dimension to be prepended to the input -> so we remove this dimension again
+                if (list() in shapein) and (forcearray):
+                    if len(ahunkout[iddout].shape) > 1: 
+                        ahunkout[iddout].shape = ahunkout[iddout].shape[1:]
+                    else:
+                        ahunkout[iddout].shape = []
+
                 posout    = 0
                 for idimpos,edimpos in enumerate(dimnoapplypos):
                     curadd    = np.mod(edimpos,len(adimnoapplyout[ihunkout][idimpos]))
